RDS2 — boto v2.27.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »

# RDS2

## boto.rds2

`boto.rds2.` `connect_to_region`(region_name, **kw_params)

  Given a valid region name, return a `boto.rds2.layer1.RDSConnection`. Any additional parameters after the region_name are passed on to the connect method of the region object.

  Type : | str
  Parameters: | region_name – The name of the region to connect to.
  Return type: | `boto.rds2.layer1.RDSConnection` or `None`
  Returns: | A connection to the given region, or None if an invalid region name is given

`boto.rds2.` `regions`()

  Get all available regions for the RDS service.

  Return type: | list
  Returns: | A list of `boto.regioninfo.RegionInfo`

## boto.rds2.exceptions

exception `boto.rds2.exceptions.` `AuthorizationAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `AuthorizationNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `AuthorizationQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBInstanceAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBInstanceNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBParameterGroupAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBParameterGroupNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBParameterGroupQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSecurityGroupAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSecurityGroupNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSecurityGroupNotSupported`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSecurityGroupQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSnapshotAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSnapshotNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSubnetGroupAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSubnetGroupDoesNotCoverEnoughAZs`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSubnetGroupNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSubnetGroupQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBSubnetQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `DBUpgradeDependencyFailure`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `EventSubscriptionQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InstanceQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InsufficientDBInstanceCapacity`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBInstanceState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBParameterGroupState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBSecurityGroupState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBSnapshotState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBSubnetGroupState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidDBSubnetState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidEventSubscriptionState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidOptionGroupState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidRestore`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidSubnet`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `InvalidVPCNetworkState`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `OptionGroupAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `OptionGroupNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `OptionGroupQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `PointInTimeRestoreNotEnabled`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `ProvisionedIopsNotAvailableInAZ`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `ReservedDBInstanceAlreadyExists`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `ReservedDBInstanceNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `ReservedDBInstanceQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `ReservedDBInstancesOfferingNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SNSInvalidTopic`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SNSNoAuthorization`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SNSTopicArnNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SnapshotQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SourceNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `StorageQuotaExceeded`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SubnetAlreadyInUse`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SubscriptionAlreadyExist`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SubscriptionCategoryNotFound`(status, reason, body=None, *args)

exception `boto.rds2.exceptions.` `SubscriptionNotFound`(status, reason, body=None, *args)

## boto.rds2.layer1

class `boto.rds2.layer1.` `RDSConnection`(**kwargs)

  Amazon Relational Database Service Amazon Relational Database Service (Amazon RDS) is a web service that makes it easier to set up, operate, and scale a relational database in the cloud. It provides cost-efficient, resizable capacity for an industry-standard relational database and manages common database administration tasks, freeing up developers to focus on what makes their applications and businesses unique.

  Amazon RDS gives you access to the capabilities of a familiar MySQL or Oracle database server. This means the code, applications, and tools you already use today with your existing MySQL or Oracle databases work with Amazon RDS without modification. Amazon RDS automatically backs up your database and maintains the database software that powers your DB instance. Amazon RDS is flexible: you can scale your database instance’s compute resources and storage capacity to meet your application’s demand. As with all Amazon Web Services, there are no up-front investments, and you pay only for the resources you use.

  This is the Amazon RDS API Reference . It contains a comprehensive description of all Amazon RDS Query APIs and data types. Note that this API is asynchronous and some actions may require polling to determine when an action has been applied. See the parameter description to determine if a change is applied immediately or on the next instance reboot or during the maintenance window. For more information on Amazon RDS concepts and usage scenarios, go to the `Amazon RDS User Guide`_.

  `APIVersion` = '2013-09-09'
  `DefaultRegionEndpoint` = 'rds.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `ResponseError`

    alias of `JSONResponseError`

  `add_source_identifier_to_subscription`(subscription_name, source_identifier)

    Adds a source identifier to an existing RDS event notification subscription.

    Parameters: | subscription_name (string) – The name of the RDS event notification subscription you want to add a source identifier to. source_identifier (string) –

    The identifier of the event source to be added. An identifier must
      begin with a letter and must contain only ASCII letters, digits, and hyphens; it cannot end with a hyphen or contain two consecutive hyphens.

    Constraints:

    - If the source type is a DB instance, then a DBInstanceIdentifier

        must be supplied.

    - If the source type is a DB security group, a DBSecurityGroupName

        must be supplied.

    - If the source type is a DB parameter group, a DBParameterGroupName

        must be supplied.

    - If the source type is a DB snapshot, a DBSnapshotIdentifier must be

        supplied.

  `add_tags_to_resource`(resource_name, tags)

    Adds metadata tags to an Amazon RDS resource. These tags can also be used with cost allocation reporting to track cost associated with Amazon RDS resources, or used in Condition statement in IAM policy for Amazon RDS.

    For an overview on tagging Amazon RDS resources, see `Tagging Amazon RDS Resources`_.

    Parameters: | resource_name (string) – The Amazon RDS resource the tags will be added to. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see ` Constructing an RDS Amazon Resource Name (ARN)`_. tags (list) – The tags to be assigned to the Amazon RDS resource.

  `authorize_db_security_group_ingress`(db_security_group_name, cidrip=None, ec2_security_group_name=None, ec2_security_group_id=None, ec2_security_group_owner_id=None)

    Enables ingress to a DBSecurityGroup using one of two forms of authorization. First, EC2 or VPC security groups can be added to the DBSecurityGroup if the application using the database is running on EC2 or VPC instances. Second, IP ranges are available if the application accessing your database is running on the Internet. Required parameters for this API are one of CIDR range, EC2SecurityGroupId for VPC, or (EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId for non-VPC). You cannot authorize ingress from an EC2 security group in one Region to an Amazon RDS DB instance in another. You cannot authorize ingress from a VPC security group in one VPC to an Amazon RDS DB instance in another. For an overview of CIDR ranges, go to the `Wikipedia Tutorial`_.

    Parameters: | db_security_group_name (string) – The name of the DB security group to add authorization to. cidrip (string) – The IP range to authorize. ec2_security_group_name (string) – Name of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. ec2_security_group_id (string) – Id of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. ec2_security_group_owner_id (string) – AWS Account Number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The AWS Access Key ID is not an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

  `copy_db_snapshot`(source_db_snapshot_identifier, target_db_snapshot_identifier, tags=None)

    Copies the specified DBSnapshot. The source DBSnapshot must be in the “available” state.

    Parameters: | source_db_snapshot_identifier (string) – The identifier for the source DB snapshot.

    Constraints:

    - Must be the identifier for a valid system snapshot in the “available”

        state.

    Example: rds:mydb-2012-04-02-00-01

    Parameters: | target_db_snapshot_identifier (string) – The identifier for the copied snapshot.

    Constraints:

    - Cannot be null, empty, or blank
    - Must contain from 1 to 255 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Example: my-db-snapshot

    Parameters: | tags (list) – A list of tags.

  `create_db_instance`(db_instance_identifier, allocated_storage, db_instance_class, engine, master_username, master_user_password, db_name=None, db_security_groups=None, vpc_security_group_ids=None, availability_zone=None, db_subnet_group_name=None, preferred_maintenance_window=None, db_parameter_group_name=None, backup_retention_period=None, preferred_backup_window=None, port=None, multi_az=None, engine_version=None, auto_minor_version_upgrade=None, license_model=None, iops=None, option_group_name=None, character_set_name=None, publicly_accessible=None, tags=None)

    Creates a new DB instance.

    Parameters: | db_name (string) – The meaning of this parameter differs according to the database engine you use.

    MySQL

    The name of the database to create when the DB instance is created. If
      this parameter is not specified, no database is created in the DB instance.

    Constraints:

    - Must contain 1 to 64 alphanumeric characters
    - Cannot be a word reserved by the specified database engine

    Type: String

    Oracle

    The Oracle System ID (SID) of the created DB instance.

    Default: ORCL

    Constraints:

    - Cannot be longer than 8 characters

    SQL Server

    Not applicable. Must be null.

    Parameters: | db_instance_identifier (string) – The DB instance identifier. This parameter is stored as a lowercase string.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens (1 to 15

        for SQL Server).

    - First character must be a letter.

    - Cannot end with a hyphen or contain two consecutive hyphens.

    Example: mydbinstance

    Parameters: | allocated_storage (integer) – The amount of storage (in gigabytes) to be initially allocated for the database instance.

    MySQL

    Constraints: Must be an integer from 5 to 1024.

    Type: Integer

    Oracle

    Constraints: Must be an integer from 10 to 1024.

    SQL Server

    Constraints: Must be an integer from 200 to 1024 (Standard Edition and
      Enterprise Edition) or from 30 to 1024 (Express Edition and Web Edition)

    Parameters: | db_instance_class (string) – The compute and memory capacity of the DB instance.

    Valid Values: `db.t1.micro | db.m1.small | db.m1.medium | db.m1.large |
      db.m1.xlarge | db.m2.xlarge |db.m2.2xlarge | db.m2.4xlarge`

    Parameters: | engine (string) – The name of the database engine to be used for this instance.

    Valid Values: MySQL | oracle-se1 | oracle-se | oracle-ee |
      sqlserver-ee | sqlserver-se | sqlserver-ex | sqlserver-web

    Parameters: | master_username (string) –

    The name of master user for the client DB instance.

    MySQL

    Constraints:

    - Must be 1 to 16 alphanumeric characters.
    - First character must be a letter.
    - Cannot be a reserved word for the chosen database engine.

    Type: String

    Oracle

    Constraints:

    - Must be 1 to 30 alphanumeric characters.
    - First character must be a letter.
    - Cannot be a reserved word for the chosen database engine.

    SQL Server

    Constraints:

    - Must be 1 to 128 alphanumeric characters.
    - First character must be a letter.
    - Cannot be a reserved word for the chosen database engine.

    Parameters: | master_user_password (string) – The password for the master database user. Can be any printable ASCII character except “/”, ‘”’, or “@”.

    Type: String

    MySQL

    Constraints: Must contain from 8 to 41 characters.

    Oracle

    Constraints: Must contain from 8 to 30 characters.

    SQL Server

    Constraints: Must contain from 8 to 128 characters.

    Parameters: | db_security_groups (list) – A list of DB security groups to associate with this DB instance.

    Default: The default DB security group for the database engine.

    Parameters: | vpc_security_group_ids (list) – A list of EC2 VPC security groups to associate with this DB instance.

    Default: The default EC2 VPC security group for the DB subnet group’s
      VPC.

    Parameters: | availability_zone (string) – The EC2 Availability Zone that the database instance will be created in.

    Default: A random, system-chosen Availability Zone in the endpoint’s
      region.

    Example: us-east-1d

    Constraint: The AvailabilityZone parameter cannot be specified if the
      MultiAZ parameter is set to True. The specified Availability Zone must be in the same region as the current endpoint.

    Parameters: | db_subnet_group_name (string) – A DB subnet group to associate with this DB instance.

    If there is no DB subnet group, then it is a non-VPC DB instance.

    Parameters: | preferred_maintenance_window (string) – The weekly time range (in UTC) during which system maintenance can occur.

    Format: ddd:hh24:mi-ddd:hh24:mi

    Default: A 30-minute window selected at random from an 8-hour block of
      time per region, occurring on a random day of the week. To see the time blocks available, see ` Adjusting the Preferred Maintenance Window`_ in the Amazon RDS User Guide.

    Valid Days: Mon, Tue, Wed, Thu, Fri, Sat, Sun

    Constraints: Minimum 30-minute window.

    Parameters: | db_parameter_group_name (string) –

    The name of the DB parameter group to associate with this DB instance.
      If this argument is omitted, the default DBParameterGroup for the specified engine will be used.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | backup_retention_period (integer) –

    The number of days for which automated backups are retained. Setting
      this parameter to a positive number enables backups. Setting this parameter to 0 disables automated backups.

    Default: 1

    Constraints:

    - Must be a value from 0 to 8

    - Cannot be set to 0 if the DB instance is a master instance with read

        replicas

    Parameters: | preferred_backup_window (string) – The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter.

    Default: A 30-minute window selected at random from an 8-hour block of
      time per region. See the Amazon RDS User Guide for the time blocks for each region from which the default backup windows are assigned.
    Constraints: Must be in the format hh24:mi-hh24:mi. Times should be
      Universal Time Coordinated (UTC). Must not conflict with the preferred maintenance window. Must be at least 30 minutes.

    Parameters: | port (integer) – The port number on which the database accepts connections.

    MySQL

    Default: 3306

    Valid Values: 1150-65535

    Type: Integer

    Oracle

    Default: 1521

    Valid Values: 1150-65535

    SQL Server

    Default: 1433

    Valid Values: 1150-65535 except for 1434 and 3389.

    Parameters: | multi_az (boolean) – Specifies if the DB instance is a Multi-AZ deployment. You cannot set the AvailabilityZone parameter if the MultiAZ parameter is set to true. engine_version (string) – The version number of the database engine to use.

    MySQL

    Example: 5.1.42

    Type: String

    Oracle

    Example: 11.2.0.2.v2

    Type: String

    SQL Server

    Example: 10.50.2789.0.v1

    Parameters: | auto_minor_version_upgrade (boolean) – Indicates that minor engine upgrades will be applied automatically to the DB instance during the maintenance window.

    Default: True

    Parameters: | license_model (string) – License model information for this DB instance.

    Valid values: license-included | bring-your-own-license | `general-
      public-license`

    Parameters: | iops (integer) – The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance.

    Constraints: Must be an integer greater than 1000.

    Parameters: | option_group_name (string) – Indicates that the DB instance should be associated with the specified option group.

    Permanent options, such as the TDE option for Oracle Advanced Security
      TDE, cannot be removed from an option group, and that option group cannot be removed from a DB instance once it is associated with a DB instance

    Parameters: | character_set_name (string) – For supported engines, indicates that the DB instance should be associated with the specified CharacterSet. publicly_accessible (boolean) – Specifies the accessibility options for the DB instance. A value of true specifies an Internet-facing instance with a publicly resolvable DNS name, which resolves to a public IP address. A value of false specifies an internal instance with a DNS name that resolves to a private IP address.

    Default: The default behavior varies depending on whether a VPC has
      been requested or not. The following list shows the default behavior in each case.
    - **Default VPC:**true
    - **VPC:**false
    If no DB subnet group has been specified as part of the request and the
      PubliclyAccessible value has not been set, the DB instance will be publicly accessible. If a specific DB subnet group has been specified as part of the request and the PubliclyAccessible value has not been set, the DB instance will be private.

    Parameters: | tags (list) – A list of tags.

  `create_db_instance_read_replica`(db_instance_identifier, source_db_instance_identifier, db_instance_class=None, availability_zone=None, port=None, auto_minor_version_upgrade=None, iops=None, option_group_name=None, publicly_accessible=None, tags=None)

    Creates a DB instance that acts as a read replica of a source DB instance.

    All read replica DB instances are created as Single-AZ deployments with backups disabled. All other DB instance attributes (including DB security groups and DB parameter groups) are inherited from the source DB instance, except as specified below.

    The source DB instance must have backup retention enabled.

    Parameters: | db_instance_identifier (string) – The DB instance identifier of the read replica. This is the unique key that identifies a DB instance. This parameter is stored as a lowercase string. source_db_instance_identifier (string) – The identifier of the DB instance that will act as the source for the read replica. Each DB instance can have up to five read replicas.

    Constraints: Must be the identifier of an existing DB instance that is
      not already a read replica DB instance.

    Parameters: | db_instance_class (string) – The compute and memory capacity of the read replica.

    Valid Values: `db.m1.small | db.m1.medium | db.m1.large | db.m1.xlarge
      db.m2.xlarge |db.m2.2xlarge | db.m2.4xlarge`

    Default: Inherits from the source DB instance.

    Parameters: | availability_zone (string) – The Amazon EC2 Availability Zone that the read replica will be created in.

    Default: A random, system-chosen Availability Zone in the endpoint’s
      region.

    Example: us-east-1d

    Parameters: | port (integer) – The port number that the DB instance uses for connections.

    Default: Inherits from the source DB instance

    Valid Values: 1150-65535

    Parameters: | auto_minor_version_upgrade (boolean) – Indicates that minor engine upgrades will be applied automatically to the read replica during the maintenance window.

    Default: Inherits from the source DB instance

    Parameters: | iops (integer) – The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance. option_group_name (string) – The option group the DB instance will be associated with. If omitted, the default option group for the engine specified will be used. publicly_accessible (boolean) – Specifies the accessibility options for the DB instance. A value of true specifies an Internet-facing instance with a publicly resolvable DNS name, which resolves to a public IP address. A value of false specifies an internal instance with a DNS name that resolves to a private IP address.

    Default: The default behavior varies depending on whether a VPC has
      been requested or not. The following list shows the default behavior in each case.
    - **Default VPC:**true
    - **VPC:**false
    If no DB subnet group has been specified as part of the request and the
      PubliclyAccessible value has not been set, the DB instance will be publicly accessible. If a specific DB subnet group has been specified as part of the request and the PubliclyAccessible value has not been set, the DB instance will be private.

    Parameters: | tags (list) – A list of tags.

  `create_db_parameter_group`(db_parameter_group_name, db_parameter_group_family, description, tags=None)

    Creates a new DB parameter group.

    A DB parameter group is initially created with the default parameters for the database engine used by the DB instance. To provide custom values for any of the parameters, you must modify the group after creating it using ModifyDBParameterGroup . Once you’ve created a DB parameter group, you need to associate it with your DB instance using ModifyDBInstance . When you associate a new DB parameter group with a running DB instance, you need to reboot the DB Instance for the new DB parameter group and associated settings to take effect.

    Parameters: | db_parameter_group_name (string) –

    The name of the DB parameter group.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    This value is stored as a lower-case string.

    Parameters: | db_parameter_group_family (string) – The DB parameter group family name. A DB parameter group can be associated with one and only one DB parameter group family, and can be applied only to a DB instance running a database engine and engine version compatible with that DB parameter group family. description (string) – The description for the DB parameter group. tags (list) – A list of tags.

  `create_db_security_group`(db_security_group_name, db_security_group_description, tags=None)

    Creates a new DB security group. DB security groups control access to a DB instance.

    Parameters: | db_security_group_name (string) – The name for the DB security group. This value is stored as a lowercase string.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens
    - Must not be “Default”
    - May not contain spaces

    Example: mysecuritygroup

    Parameters: | db_security_group_description (string) – The description for the DB security group. tags (list) – A list of tags.

  `create_db_snapshot`(db_snapshot_identifier, db_instance_identifier, tags=None)

    Creates a DBSnapshot. The source DBInstance must be in “available” state.

    Parameters: | db_snapshot_identifier (string) – The identifier for the DB snapshot.

    Constraints:

    - Cannot be null, empty, or blank
    - Must contain from 1 to 255 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Example: my-snapshot-id

    Parameters: | db_instance_identifier (string) –

    The DB instance identifier. This is the unique key that identifies a DB
      instance. This parameter isn’t case sensitive.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | tags (list) – A list of tags.

  `create_db_subnet_group`(db_subnet_group_name, db_subnet_group_description, subnet_ids, tags=None)

    Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the region.

    Parameters: | db_subnet_group_name (string) – The name for the DB subnet group. This value is stored as a lowercase string.

    Constraints: Must contain no more than 255 alphanumeric characters or
      hyphens. Must not be “Default”.

    Example: mySubnetgroup

    Parameters: | db_subnet_group_description (string) – The description for the DB subnet group. subnet_ids (list) – The EC2 Subnet IDs for the DB subnet group. tags (list) – A list of tags.

  `create_event_subscription`(subscription_name, sns_topic_arn, source_type=None, event_categories=None, source_ids=None, enabled=None, tags=None)

    Creates an RDS event notification subscription. This action requires a topic ARN (Amazon Resource Name) created by either the RDS console, the SNS console, or the SNS API. To obtain an ARN with SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console.

    You can specify the type of source (SourceType) you want to be notified of, provide a list of RDS sources (SourceIds) that triggers the events, and provide a list of event categories (EventCategories) for events you want to be notified of. For example, you can specify SourceType = db-instance, SourceIds = mydbinstance1, mydbinstance2 and EventCategories = Availability, Backup.

    If you specify both the SourceType and SourceIds, such as SourceType = db-instance and SourceIdentifier = myDBInstance1, you will be notified of all the db-instance events for the specified source. If you specify a SourceType but do not specify a SourceIdentifier, you will receive notice of the events for that source type for all your RDS sources. If you do not specify either the SourceType nor the SourceIdentifier, you will be notified of events generated from all RDS sources belonging to your customer account.

    Parameters: | subscription_name (string) – The name of the subscription.

    Constraints: The name must be less than 255 characters.

    Parameters: | sns_topic_arn (string) – The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it. source_type (string) – The type of source that will be generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. if this value is not specified, all events are returned.

    Valid values: db-instance | db-parameter-group | db-security-group |
      db-snapshot

    Parameters: | event_categories (list) – A list of event categories for a SourceType that you want to subscribe to. You can see a list of the categories for a given SourceType in the `Events`_ topic in the Amazon RDS User Guide or by using the DescribeEventCategories action. source_ids (list) –

    The list of identifiers of the event sources for which events will be
      returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it cannot end with a hyphen or contain two consecutive hyphens.

    Constraints:

    - If SourceIds are supplied, SourceType must also be provided.

    - If the source type is a DB instance, then a DBInstanceIdentifier

        must be supplied.

    - If the source type is a DB security group, a DBSecurityGroupName

        must be supplied.

    - If the source type is a DB parameter group, a DBParameterGroupName

        must be supplied.

    - If the source type is a DB snapshot, a DBSnapshotIdentifier must be

        supplied.

    Parameters: | enabled (boolean) – A Boolean value; set to true to activate the subscription, set to false to create the subscription but not active it. tags (list) – A list of tags.

  `create_option_group`(option_group_name, engine_name, major_engine_version, option_group_description, tags=None)

    Creates a new option group. You can create up to 20 option groups.

    Parameters: | option_group_name (string) – Specifies the name of the option group to be created.

    Constraints:

    - Must be 1 to 255 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Example: myoptiongroup

    Parameters: | engine_name (string) – Specifies the name of the engine that this option group should be associated with. major_engine_version (string) – Specifies the major version of the engine that this option group should be associated with. option_group_description (string) – The description of the option group. tags (list) – A list of tags.

  `delete_db_instance`(db_instance_identifier, skip_final_snapshot=None, final_db_snapshot_identifier=None)

    The DeleteDBInstance action deletes a previously provisioned DB instance. A successful response from the web service indicates the request was received correctly. When you delete a DB instance, all automated backups for that instance are deleted and cannot be recovered. Manual DB snapshots of the DB instance to be deleted are not deleted.

    If a final DB snapshot is requested the status of the RDS instance will be “deleting” until the DB snapshot is created. The API action DescribeDBInstance is used to monitor the status of this operation. The action cannot be canceled or reverted once submitted.

    Parameters: | db_instance_identifier (string) –

    The DB instance identifier for the DB instance to be deleted. This
      parameter isn’t case sensitive.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | skip_final_snapshot (boolean) – Determines whether a final DB snapshot is created before the DB instance is deleted. If True is specified, no DBSnapshot is created. If false is specified, a DB snapshot is created before the DB instance is deleted.

    The FinalDBSnapshotIdentifier parameter must be specified if
      SkipFinalSnapshot is False.

    Default: False

    Parameters: | final_db_snapshot_identifier (string) –

    The DBSnapshotIdentifier of the new DBSnapshot created when
      SkipFinalSnapshot is set to False.
    Specifying this parameter and also setting the SkipFinalShapshot
      parameter to true results in an error.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens
  `delete_db_parameter_group`(db_parameter_group_name)

    Deletes a specified DBParameterGroup. The DBParameterGroup cannot be associated with any RDS instances to be deleted. The specified DB parameter group cannot be associated with any DB instances.

    Parameters: | db_parameter_group_name (string) –

    The name of the DB parameter group.

    Constraints:

    - Must be the name of an existing DB parameter group
    - You cannot delete a default DB parameter group
    - Cannot be associated with any DB instances
  `delete_db_security_group`(db_security_group_name)

    Deletes a DB security group. The specified DB security group must not be associated with any DB instances.

    Parameters: | db_security_group_name (string) –

    The name of the DB security group to delete.

    You cannot delete the default DB security group.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens
    - Must not be “Default”
    - May not contain spaces
  `delete_db_snapshot`(db_snapshot_identifier)

    Deletes a DBSnapshot. The DBSnapshot must be in the available state to be deleted.

    Parameters: | db_snapshot_identifier (string) – The DBSnapshot identifier.

    Constraints: Must be the name of an existing DB snapshot in the
      available state.
  `delete_db_subnet_group`(db_subnet_group_name)

    Deletes a DB subnet group. The specified database subnet group must not be associated with any DB instances.

    Parameters: | db_subnet_group_name (string) –

    The name of the database subnet group to delete.

    You cannot delete the default subnet group.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens
  `delete_event_subscription`(subscription_name)

    Deletes an RDS event notification subscription.

    Parameters: | subscription_name (string) – The name of the RDS event notification subscription you want to delete.

  `delete_option_group`(option_group_name)

    Deletes an existing option group.

    Parameters: | option_group_name (string) –

    The name of the option group to be deleted.

    You cannot delete default option groups.

  `describe_db_engine_versions`(engine=None, engine_version=None, db_parameter_group_family=None, max_records=None, marker=None, default_only=None, list_supported_character_sets=None)

    Returns a list of the available DB engines.

    Parameters: | engine (string) – The database engine to return. engine_version (string) – The database engine version to return.

    Example: 5.1.49

    Parameters: | db_parameter_group_family (string) –

    The name of a specific DB parameter group family to return details for.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | max_records (integer) – The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so that the following results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. default_only (boolean) – Indicates that only the default version of the specified engine or engine and major version combination is returned. list_supported_character_sets (boolean) – If this parameter is specified, and if the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version.

  `describe_db_instances`(db_instance_identifier=None, filters=None, max_records=None, marker=None)

    Returns information about provisioned RDS instances. This API supports pagination.

    Parameters: | db_instance_identifier (string) –

    The user-supplied instance identifier. If this parameter is specified,
      information from only the specific DB instance is returned. This parameter isn’t case sensitive.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBInstances request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .

  `describe_db_log_files`(db_instance_identifier, filename_contains=None, file_last_written=None, file_size=None, max_records=None, marker=None)

    Returns a list of DB log files for the DB instance.

    Parameters: | db_instance_identifier (string) –

    The customer-assigned name of the DB instance that contains the log
      files you want to list.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | filename_contains (string) – Filters the available log files for log file names that contain the specified string. file_last_written (long) – Filters the available log files for files written since the specified date, in POSIX timestamp format. file_size (long) – Filters the available log files for files larger than the specified size. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved. marker (string) – The pagination token provided in the previous request. If this parameter is specified the response includes only records beyond the marker, up to MaxRecords.

  `describe_db_parameter_groups`(db_parameter_group_name=None, filters=None, max_records=None, marker=None)

    Returns a list of DBParameterGroup descriptions. If a DBParameterGroupName is specified, the list will contain only the description of the specified DB parameter group.

    Parameters: | db_parameter_group_name (string) –

    The name of a specific DB parameter group to return details for.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBParameterGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_db_parameters`(db_parameter_group_name, source=None, max_records=None, marker=None)

    Returns the detailed parameter list for a particular DB parameter group.

    Parameters: | db_parameter_group_name (string) –

    The name of a specific DB parameter group to return details for.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | source (string) – The parameter types to return.

    Default: All parameter types returned

    Valid Values: user | system | engine-default

    Parameters: | max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_db_security_groups`(db_security_group_name=None, filters=None, max_records=None, marker=None)

    Returns a list of DBSecurityGroup descriptions. If a DBSecurityGroupName is specified, the list will contain only the descriptions of the specified DB security group.

    Parameters: | db_security_group_name (string) – The name of the DB security group to return details for. filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBSecurityGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_db_snapshots`(db_instance_identifier=None, db_snapshot_identifier=None, snapshot_type=None, filters=None, max_records=None, marker=None)

    Returns information about DB snapshots. This API supports pagination.

    Parameters: | db_instance_identifier (string) –

    A DB instance identifier to retrieve the list of DB snapshots for.
      Cannot be used in conjunction with DBSnapshotIdentifier. This parameter is not case sensitive.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | db_snapshot_identifier (string) –

    A specific DB snapshot identifier to describe. Cannot be used in
      conjunction with DBInstanceIdentifier. This value is stored as a lowercase string.

    Constraints:

    - Must be 1 to 255 alphanumeric characters

    - First character must be a letter

    - Cannot end with a hyphen or contain two consecutive hyphens

    - If this is the identifier of an automated snapshot, the

        SnapshotType parameter must also be specified.

    Parameters: | snapshot_type (string) – The type of snapshots that will be returned. Values can be “automated” or “manual.” If not specified, the returned results will include all snapshots types. filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBSnapshots request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_db_subnet_groups`(db_subnet_group_name=None, filters=None, max_records=None, marker=None)

    Returns a list of DBSubnetGroup descriptions. If a DBSubnetGroupName is specified, the list will contain only the descriptions of the specified DBSubnetGroup.

    For an overview of CIDR ranges, go to the `Wikipedia Tutorial`_.

    Parameters: | db_subnet_group_name (string) – The name of the DB subnet group to return details for. filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeDBSubnetGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_engine_default_parameters`(db_parameter_group_family, max_records=None, marker=None)

    Returns the default engine and system parameter information for the specified database engine.

    Parameters: | db_parameter_group_family (string) – The name of the DB parameter group family. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeEngineDefaultParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_event_categories`(source_type=None)

    Displays a list of categories for all event source types, or, if specified, for a specified source type. You can see a list of the event categories and source types in the ` Events`_ topic in the Amazon RDS User Guide.

    Parameters: | source_type (string) – The type of source that will be generating the events.

    Valid values: db-instance | db-parameter-group | db-security-group |
      db-snapshot
  `describe_event_subscriptions`(subscription_name=None, filters=None, max_records=None, marker=None)

    Lists all the subscription descriptions for a customer account. The description for a subscription includes SubscriptionName, SNSTopicARN, CustomerID, SourceType, SourceID, CreationTime, and Status.

    If you specify a SubscriptionName, lists the description for that subscription.

    Parameters: | subscription_name (string) – The name of the RDS event notification subscription you want to describe. filters (list) – max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .

  `describe_events`(source_identifier=None, source_type=None, start_time=None, end_time=None, duration=None, event_categories=None, max_records=None, marker=None)

    Returns events related to DB instances, DB security groups, DB snapshots, and DB parameter groups for the past 14 days. Events specific to a particular DB instance, DB security group, database snapshot, or DB parameter group can be obtained by providing the name as a parameter. By default, the past hour of events are returned.

    Parameters: | source_identifier (string) –

    The identifier of the event source for which events will be returned.
      If not specified, then all sources are included in the response.

    Constraints:

    - If SourceIdentifier is supplied, SourceType must also be provided.

    - If the source type is DBInstance, then a DBInstanceIdentifier

        must be supplied.

    - If the source type is DBSecurityGroup, a DBSecurityGroupName must

        be supplied.

    - If the source type is DBParameterGroup, a DBParameterGroupName

        must be supplied.

    - If the source type is DBSnapshot, a DBSnapshotIdentifier must be

        supplied.

    - Cannot end with a hyphen or contain two consecutive hyphens.

    Parameters: | source_type (string) – The event source to retrieve events for. If no value is specified, all events are returned. start_time (timestamp) – The beginning of the time interval to retrieve events for, specified in ISO 8601 format. For more information about ISO 8601, go to the `ISO8601 Wikipedia page.`_

    Example: 2009-07-08T18:00Z

    Parameters: | end_time (timestamp) – The end of the time interval for which to retrieve events, specified in ISO 8601 format. For more information about ISO 8601, go to the `ISO8601 Wikipedia page.`_

    Example: 2009-07-08T18:00Z

    Parameters: | duration (integer) – The number of minutes to retrieve events for.

    Default: 60

    Parameters: | event_categories (list) – A list of event categories that trigger notifications for a event notification subscription. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results may be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeEvents request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_option_group_options`(engine_name, major_engine_version=None, max_records=None, marker=None)

    Describes all available options.

    Parameters: | engine_name (string) – A required parameter. Options available for the given Engine name will be described. major_engine_version (string) – If specified, filters the results to include only options for the specified major engine version. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_option_groups`(option_group_name=None, filters=None, marker=None, max_records=None, engine_name=None, major_engine_version=None)

    Describes the available option groups.

    Parameters: | option_group_name (string) – The name of the option group to describe. Cannot be supplied together with EngineName or MajorEngineVersion. filters (list) – marker (string) – An optional pagination token provided by a previous DescribeOptionGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | engine_name (string) – Filters the list of option groups to only include groups associated with a specific database engine. major_engine_version (string) – Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then EngineName must also be specified.

  `describe_orderable_db_instance_options`(engine, engine_version=None, db_instance_class=None, license_model=None, vpc=None, max_records=None, marker=None)

    Returns a list of orderable DB instance options for the specified engine.

    Parameters: | engine (string) – The name of the engine to retrieve DB instance options for. engine_version (string) – The engine version filter value. Specify this parameter to show only the available offerings matching the specified engine version. db_instance_class (string) – The DB instance class filter value. Specify this parameter to show only the available offerings matching the specified DB instance class. license_model (string) – The license model filter value. Specify this parameter to show only the available offerings matching the specified license model. vpc (boolean) – The VPC filter value. Specify this parameter to show only the available VPC or non-VPC offerings. max_records (integer) – The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .

  `describe_reserved_db_instances`(reserved_db_instance_id=None, reserved_db_instances_offering_id=None, db_instance_class=None, duration=None, product_description=None, offering_type=None, multi_az=None, filters=None, max_records=None, marker=None)

    Returns information about reserved DB instances for this account, or about a specified reserved DB instance.

    Parameters: | reserved_db_instance_id (string) – The reserved DB instance identifier filter value. Specify this parameter to show only the reservation that matches the specified reservation ID. reserved_db_instances_offering_id (string) – The offering identifier filter value. Specify this parameter to show only purchased reservations matching the specified offering identifier. db_instance_class (string) – The DB instance class filter value. Specify this parameter to show only those reservations matching the specified DB instances class. duration (string) – The duration filter value, specified in years or seconds. Specify this parameter to show only reservations for this duration.

    Valid Values: 1 | 3 | 31536000 | 94608000

    Parameters: | product_description (string) – The product description filter value. Specify this parameter to show only those reservations matching the specified product description. offering_type (string) – The offering type filter value. Specify this parameter to show only the available offerings matching the specified offering type.

    Valid Values: `“Light Utilization” | “Medium Utilization” | “Heavy
      Utilization” `

    Parameters: | multi_az (boolean) – The Multi-AZ filter value. Specify this parameter to show only those reservations matching the specified Multi-AZ parameter. filters (list) – max_records (integer) – The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so that the following results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `describe_reserved_db_instances_offerings`(reserved_db_instances_offering_id=None, db_instance_class=None, duration=None, product_description=None, offering_type=None, multi_az=None, max_records=None, marker=None)

    Lists available reserved DB instance offerings.

    Parameters: | reserved_db_instances_offering_id (string) – The offering identifier filter value. Specify this parameter to show only the available offering that matches the specified reservation identifier.

    Example: 438012d3-4052-4cc7-b2e3-8d3372e0e706

    Parameters: | db_instance_class (string) – The DB instance class filter value. Specify this parameter to show only the available offerings matching the specified DB instance class. duration (string) – Duration filter value, specified in years or seconds. Specify this parameter to show only reservations for this duration.

    Valid Values: 1 | 3 | 31536000 | 94608000

    Parameters: | product_description (string) – Product description filter value. Specify this parameter to show only the available offerings matching the specified product description. offering_type (string) – The offering type filter value. Specify this parameter to show only the available offerings matching the specified offering type.

    Valid Values: `“Light Utilization” | “Medium Utilization” | “Heavy
      Utilization” `

    Parameters: | multi_az (boolean) – The Multi-AZ filter value. Specify this parameter to show only the available offerings matching the specified Multi-AZ parameter. max_records (integer) – The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so that the following results can be retrieved.

    Default: 100

    Constraints: minimum 20, maximum 100

    Parameters: | marker (string) – An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  `download_db_log_file_portion`(db_instance_identifier, log_file_name, marker=None, number_of_lines=None)

    Downloads the last line of the specified log file.

    Parameters: | db_instance_identifier (string) –

    The customer-assigned name of the DB instance that contains the log
      files you want to list.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | log_file_name (string) – The name of the log file to be downloaded. marker (string) – The pagination token provided in the previous request. If this parameter is specified the response includes only records beyond the marker, up to MaxRecords. number_of_lines (integer) – The number of lines remaining to be downloaded.

  `list_tags_for_resource`(resource_name)

    Lists all tags on an Amazon RDS resource.

    For an overview on tagging an Amazon RDS resource, see `Tagging Amazon RDS Resources`_.

    Parameters: | resource_name (string) – The Amazon RDS resource with tags to be listed. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see ` Constructing an RDS Amazon Resource Name (ARN)`_.

  `modify_db_instance`(db_instance_identifier, allocated_storage=None, db_instance_class=None, db_security_groups=None, vpc_security_group_ids=None, apply_immediately=None, master_user_password=None, db_parameter_group_name=None, backup_retention_period=None, preferred_backup_window=None, preferred_maintenance_window=None, multi_az=None, engine_version=None, allow_major_version_upgrade=None, auto_minor_version_upgrade=None, iops=None, option_group_name=None, new_db_instance_identifier=None)

    Modify settings for a DB instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request.

    Parameters: | db_instance_identifier (string) –

    The DB instance identifier. This value is stored as a lowercase string.

    Constraints:

    - Must be the identifier for an existing DB instance
    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | allocated_storage (integer) – The new storage capacity of the RDS instance. Changing this parameter does not result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request.

    MySQL

    Default: Uses existing setting

    Valid Values: 5-1024

    Constraints: Value supplied must be at least 10% greater than the
      current value. Values that are not at least 10% greater than the existing value are rounded up so that they are 10% greater than the current value.

    Type: Integer

    Oracle

    Default: Uses existing setting

    Valid Values: 10-1024

    Constraints: Value supplied must be at least 10% greater than the
      current value. Values that are not at least 10% greater than the existing value are rounded up so that they are 10% greater than the current value.

    SQL Server

    Cannot be modified.

    If you choose to migrate your DB instance from using standard storage
      to using Provisioned IOPS, or from using Provisioned IOPS to using standard storage, the process can take time. The duration of the migration depends on several factors such as database load, storage size, storage type (standard or Provisioned IOPS), amount of IOPS provisioned (if any), and the number of prior scale storage operations. Typical migration times are under 24 hours, but the process can take up to several days in some cases. During the migration, the DB instance will be available for use, but may experience performance degradation. While the migration takes place, nightly backups for the instance will be suspended. No other Amazon RDS operations can take place for the instance, including modifying the instance, rebooting the instance, deleting the instance, creating a read replica for the instance, and creating a DB snapshot of the instance.

    Parameters: | db_instance_class (string) – The new compute and memory capacity of the DB instance. To determine the instance classes that are available for a particular DB engine, use the DescribeOrderableDBInstanceOptions action.

    Passing a value for this parameter causes an outage during the change
      and is applied during the next maintenance window, unless the ApplyImmediately parameter is specified as True for this request.

    Default: Uses existing setting

    Valid Values: `db.t1.micro | db.m1.small | db.m1.medium | db.m1.large |
      db.m1.xlarge | db.m2.xlarge | db.m2.2xlarge | db.m2.4xlarge`

    Parameters: | db_security_groups (list) –

    A list of DB security groups to authorize on this DB instance. Changing
      this parameter does not result in an outage and the change is asynchronously applied as soon as possible.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | vpc_security_group_ids (list) –

    A list of EC2 VPC security groups to authorize on this DB instance.
      This change is asynchronously applied as soon as possible.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | apply_immediately (boolean) – Specifies whether or not the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the PreferredMaintenanceWindow setting for the DB instance.

    If this parameter is passed as False, changes to the DB instance are
      applied on the next call to RebootDBInstance, the next maintenance reboot, or the next failure reboot, whichever occurs first. See each parameter to determine when a change is applied.

    Default: False

    Parameters: | master_user_password (string) –

    The new password for the DB instance master user. Can be any printable
      ASCII character except “/”, ‘”’, or “@”.
    Changing this parameter does not result in an outage and the change is
      asynchronously applied as soon as possible. Between the time of the request and the completion of the request, the MasterUserPassword element exists in the PendingModifiedValues element of the operation response.

    Default: Uses existing setting

    Constraints: Must be 8 to 41 alphanumeric characters (MySQL), 8 to 30
      alphanumeric characters (Oracle), or 8 to 128 alphanumeric characters (SQL Server).
    Amazon RDS API actions never return the password, so this action
      provides a way to regain access to a master instance user if the password is lost.

    Parameters: | db_parameter_group_name (string) – The name of the DB parameter group to apply to this DB instance. Changing this parameter does not result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request.

    Default: Uses existing setting

    Constraints: The DB parameter group must be in the same DB parameter
      group family as this DB instance.

    Parameters: | backup_retention_period (integer) –

    The number of days to retain automated backups. Setting this parameter
      to a positive number enables backups. Setting this parameter to 0 disables automated backups.
    Changing this parameter can result in an outage if you change from 0 to
      a non-zero value or from a non-zero value to 0. These changes are applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request. If you change the parameter from one non-zero value to another non- zero value, the change is asynchronously applied as soon as possible.

    Default: Uses existing setting

    Constraints:

    - Must be a value from 0 to 8

    - Cannot be set to 0 if the DB instance is a master instance with read

        replicas or if the DB instance is a read replica

    Parameters: | preferred_backup_window (string) –

    The daily time range during which automated backups are created if
      automated backups are enabled, as determined by the BackupRetentionPeriod. Changing this parameter does not result in an outage and the change is asynchronously applied as soon as possible.

    Constraints:

    - Must be in the format hh24:mi-hh24:mi
    - Times should be Universal Time Coordinated (UTC)
    - Must not conflict with the preferred maintenance window
    - Must be at least 30 minutes

    Parameters: | preferred_maintenance_window (string) – The weekly time range (in UTC) during which system maintenance can occur, which may result in an outage. Changing this parameter does not result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, then changing this parameter will cause a reboot of the DB instance. If moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied.

    Default: Uses existing setting

    Format: ddd:hh24:mi-ddd:hh24:mi

    Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun

    Constraints: Must be at least 30 minutes

    Parameters: | multi_az (boolean) – Specifies if the DB instance is a Multi-AZ deployment. Changing this parameter does not result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request.

    Constraints: Cannot be specified if the DB instance is a read replica.

    Parameters: | engine_version (string) – The version number of the database engine to upgrade to. Changing this parameter results in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request.

    For major version upgrades, if a non-default DB parameter group is
      currently in use, a new DB parameter group in the DB parameter group family for the new engine version must be specified. The new DB parameter group can be the default for that DB parameter group family.

    Example: 5.1.42

    Parameters: | allow_major_version_upgrade (boolean) – Indicates that major version upgrades are allowed. Changing this parameter does not result in an outage and the change is asynchronously applied as soon as possible.

    Constraints: This parameter must be set to true when specifying a value
      for the EngineVersion parameter that is a different major version than the DB instance’s current version.

    Parameters: | auto_minor_version_upgrade (boolean) – Indicates that minor version upgrades will be applied automatically to the DB instance during the maintenance window. Changing this parameter does not result in an outage except in the following case and the change is asynchronously applied as soon as possible. An outage will result if this parameter is set to True during the maintenance window, and a newer minor version is available, and RDS has enabled auto patching for that engine version. iops (integer) – The new Provisioned IOPS (I/O operations per second) value for the RDS instance. Changing this parameter does not result in an outage and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request.

    Default: Uses existing setting

    Constraints: Value supplied must be at least 10% greater than the
      current value. Values that are not at least 10% greater than the existing value are rounded up so that they are 10% greater than the current value.

    Type: Integer

    If you choose to migrate your DB instance from using standard storage
      to using Provisioned IOPS, or from using Provisioned IOPS to using standard storage, the process can take time. The duration of the migration depends on several factors such as database load, storage size, storage type (standard or Provisioned IOPS), amount of IOPS provisioned (if any), and the number of prior scale storage operations. Typical migration times are under 24 hours, but the process can take up to several days in some cases. During the migration, the DB instance will be available for use, but may experience performance degradation. While the migration takes place, nightly backups for the instance will be suspended. No other Amazon RDS operations can take place for the instance, including modifying the instance, rebooting the instance, deleting the instance, creating a read replica for the instance, and creating a DB snapshot of the instance.

    Parameters: | option_group_name (string) – Indicates that the DB instance should be associated with the specified option group. Changing this parameter does not result in an outage except in the following case and the change is applied during the next maintenance window unless the ApplyImmediately parameter is set to True for this request. If the parameter change results in an option group that enables OEM, this change can cause a brief (sub-second) period during which new connections are rejected but existing connections are not interrupted.

    Permanent options, such as the TDE option for Oracle Advanced Security
      TDE, cannot be removed from an option group, and that option group cannot be removed from a DB instance once it is associated with a DB instance

    Parameters: | new_db_instance_identifier (string) –

    The new DB instance identifier for the DB instance when renaming a DB
      Instance. This value is stored as a lowercase string.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens
  `modify_db_parameter_group`(db_parameter_group_name, parameters)

    Modifies the parameters of a DB parameter group. To modify more than one parameter, submit a list of the following: ParameterName, ParameterValue, and ApplyMethod. A maximum of 20 parameters can be modified in a single request.

    The apply-immediate method can be used only for dynamic parameters; the pending-reboot method can be used with MySQL and Oracle DB instances for either dynamic or static parameters. For Microsoft SQL Server DB instances, the pending-reboot method can be used only for static parameters.

    Parameters: | db_parameter_group_name (string) –

    The name of the DB parameter group.

    Constraints:

    - Must be the name of an existing DB parameter group
    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | parameters (list) –

    An array of parameter names, values, and the apply method for the
      parameter update. At least one parameter name, value, and apply method must be supplied; subsequent arguments are optional. A maximum of 20 parameters may be modified in a single request.

    Valid Values (for the application method): immediate | pending-reboot

    You can use the immediate value with dynamic parameters only. You can
      use the pending-reboot value for both dynamic and static parameters, and changes are applied when DB instance reboots.
  `modify_db_subnet_group`(db_subnet_group_name, subnet_ids, db_subnet_group_description=None)

    Modifies an existing DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the region.

    Parameters: | db_subnet_group_name (string) – The name for the DB subnet group. This value is stored as a lowercase string.

    Constraints: Must contain no more than 255 alphanumeric characters or
      hyphens. Must not be “Default”.

    Example: mySubnetgroup

    Parameters: | db_subnet_group_description (string) – The description for the DB subnet group. subnet_ids (list) – The EC2 subnet IDs for the DB subnet group.

  `modify_event_subscription`(subscription_name, sns_topic_arn=None, source_type=None, event_categories=None, enabled=None)

    Modifies an existing RDS event notification subscription. Note that you cannot modify the source identifiers using this call; to change source identifiers for a subscription, use the AddSourceIdentifierToSubscription and RemoveSourceIdentifierFromSubscription calls.

    You can see a list of the event categories for a given SourceType in the `Events`_ topic in the Amazon RDS User Guide or by using the DescribeEventCategories action.

    Parameters: | subscription_name (string) – The name of the RDS event notification subscription. sns_topic_arn (string) – The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it. source_type (string) – The type of source that will be generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. if this value is not specified, all events are returned.

    Valid values: db-instance | db-parameter-group | db-security-group |
      db-snapshot

    Parameters: | event_categories (list) – A list of event categories for a SourceType that you want to subscribe to. You can see a list of the categories for a given SourceType in the `Events`_ topic in the Amazon RDS User Guide or by using the DescribeEventCategories action. enabled (boolean) – A Boolean value; set to true to activate the subscription.

  `modify_option_group`(option_group_name, options_to_include=None, options_to_remove=None, apply_immediately=None)

    Modifies an existing option group.

    Parameters: | option_group_name (string) – The name of the option group to be modified.

    Permanent options, such as the TDE option for Oracle Advanced Security
      TDE, cannot be removed from an option group, and that option group cannot be removed from a DB instance once it is associated with a DB instance

    Parameters: | options_to_include (list) – Options in this list are added to the option group or, if already present, the specified configuration is used to update the existing configuration. options_to_remove (list) – Options in this list are removed from the option group. apply_immediately (boolean) – Indicates whether the changes should be applied immediately, or during the next maintenance window for each instance associated with the option group.

  `promote_read_replica`(db_instance_identifier, backup_retention_period=None, preferred_backup_window=None)

    Promotes a read replica DB instance to a standalone DB instance.

    Parameters: | db_instance_identifier (string) – The DB instance identifier. This value is stored as a lowercase string.

    Constraints:

    - Must be the identifier for an existing read replica DB instance
    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Example: mydbinstance

    Parameters: | backup_retention_period (integer) –

    The number of days to retain automated backups. Setting this parameter
      to a positive number enables backups. Setting this parameter to 0 disables automated backups.

    Default: 1

    Constraints:

    - Must be a value from 0 to 8

    Parameters: | preferred_backup_window (string) – The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter.

    Default: A 30-minute window selected at random from an 8-hour block of
      time per region. See the Amazon RDS User Guide for the time blocks for each region from which the default backup windows are assigned.
    Constraints: Must be in the format hh24:mi-hh24:mi. Times should be
      Universal Time Coordinated (UTC). Must not conflict with the preferred maintenance window. Must be at least 30 minutes.
  `purchase_reserved_db_instances_offering`(reserved_db_instances_offering_id, reserved_db_instance_id=None, db_instance_count=None, tags=None)

    Purchases a reserved DB instance offering.

    Parameters: | reserved_db_instances_offering_id (string) – The ID of the Reserved DB instance offering to purchase.

    Example: 438012d3-4052-4cc7-b2e3-8d3372e0e706

    Parameters: | reserved_db_instance_id (string) – Customer-specified identifier to track this reservation.

    Example: myreservationID

    Parameters: | db_instance_count (integer) – The number of instances to reserve.

    Default: 1

    Parameters: | tags (list) – A list of tags.

  `reboot_db_instance`(db_instance_identifier, force_failover=None)

    Rebooting a DB instance restarts the database engine service. A reboot also applies to the DB instance any modifications to the associated DB parameter group that were pending. Rebooting a DB instance results in a momentary outage of the instance, during which the DB instance status is set to rebooting. If the RDS instance is configured for MultiAZ, it is possible that the reboot will be conducted through a failover. An Amazon RDS event is created when the reboot is completed.

    If your DB instance is deployed in multiple Availability Zones, you can force a failover from one AZ to the other during the reboot. You might force a failover to test the availability of your DB instance deployment or to restore operations to the original AZ after a failover occurs.

    The time required to reboot is a function of the specific database engine’s crash recovery process. To improve the reboot time, we recommend that you reduce database activities as much as possible during the reboot process to reduce rollback activity for in-transit transactions.

    Parameters: | db_instance_identifier (string) –

    The DB instance identifier. This parameter is stored as a lowercase
      string.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | force_failover (boolean) – When True, the reboot will be conducted through a MultiAZ failover.

    Constraint: You cannot specify True if the instance is not configured
      for MultiAZ.
  `remove_source_identifier_from_subscription`(subscription_name, source_identifier)

    Removes a source identifier from an existing RDS event notification subscription.

    Parameters: | subscription_name (string) – The name of the RDS event notification subscription you want to remove a source identifier from. source_identifier (string) – The source identifier to be removed from the subscription, such as the DB instance identifier for a DB instance or the name of a security group.

  `remove_tags_from_resource`(resource_name, tag_keys)

    Removes metadata tags from an Amazon RDS resource.

    For an overview on tagging an Amazon RDS resource, see `Tagging Amazon RDS Resources`_.

    Parameters: | resource_name (string) – The Amazon RDS resource the tags will be removed from. This value is an Amazon Resource Name (ARN). For information about creating an ARN, see ` Constructing an RDS Amazon Resource Name (ARN)`_. tag_keys (list) – The tag key (name) of the tag to be removed.

  `reset_db_parameter_group`(db_parameter_group_name, reset_all_parameters=None, parameters=None)

    Modifies the parameters of a DB parameter group to the engine/system default value. To reset specific parameters submit a list of the following: ParameterName and ApplyMethod. To reset the entire DB parameter group, specify the DBParameterGroup name and ResetAllParameters parameters. When resetting the entire group, dynamic parameters are updated immediately and static parameters are set to pending-reboot to take effect on the next DB instance restart or RebootDBInstance request.

    Parameters: | db_parameter_group_name (string) –

    The name of the DB parameter group.

    Constraints:

    - Must be 1 to 255 alphanumeric characters
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | reset_all_parameters (boolean) – Specifies whether ( True) or not ( False) to reset all parameters in the DB parameter group to default values.

    Default: True

    Parameters: | parameters (list) – An array of parameter names, values, and the apply method for the parameter update. At least one parameter name, value, and apply method must be supplied; subsequent arguments are optional. A maximum of 20 parameters may be modified in a single request.

    MySQL

    Valid Values (for Apply method): immediate | pending-reboot

    You can use the immediate value with dynamic parameters only. You can
      use the pending-reboot value for both dynamic and static parameters, and changes are applied when DB instance reboots.

    Oracle

    Valid Values (for Apply method): pending-reboot

  `restore_db_instance_from_db_snapshot`(db_instance_identifier, db_snapshot_identifier, db_instance_class=None, port=None, availability_zone=None, db_subnet_group_name=None, multi_az=None, publicly_accessible=None, auto_minor_version_upgrade=None, license_model=None, db_name=None, engine=None, iops=None, option_group_name=None, tags=None)

    Creates a new DB instance from a DB snapshot. The target database is created from the source database restore point with the same configuration as the original source database, except that the new RDS instance is created with the default security group.

    Parameters: | db_instance_identifier (string) –

    The identifier for the DB snapshot to restore from.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | db_snapshot_identifier (string) – Name of the DB instance to create from the DB snapshot. This parameter isn’t case sensitive.

    Constraints:

    - Must contain from 1 to 255 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Example: my-snapshot-id

    Parameters: | db_instance_class (string) – The compute and memory capacity of the Amazon RDS DB instance.

    Valid Values: `db.t1.micro | db.m1.small | db.m1.medium | db.m1.large |
      db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge`

    Parameters: | port (integer) – The port number on which the database accepts connections.

    Default: The same port as the original DB instance

    Constraints: Value must be 1150-65535

    Parameters: | availability_zone (string) – The EC2 Availability Zone that the database instance will be created in.

    Default: A random, system-chosen Availability Zone.

    Constraint: You cannot specify the AvailabilityZone parameter if the
      MultiAZ parameter is set to True.

    Example: us-east-1a

    Parameters: | db_subnet_group_name (string) – The DB subnet group name to use for the new instance. multi_az (boolean) – Specifies if the DB instance is a Multi-AZ deployment.

    Constraint: You cannot specify the AvailabilityZone parameter if the
      MultiAZ parameter is set to True.

    Parameters: | publicly_accessible (boolean) – Specifies the accessibility options for the DB instance. A value of true specifies an Internet-facing instance with a publicly resolvable DNS name, which resolves to a public IP address. A value of false specifies an internal instance with a DNS name that resolves to a private IP address.

    Default: The default behavior varies depending on whether a VPC has
      been requested or not. The following list shows the default behavior in each case.
    - **Default VPC:**true
    - **VPC:**false
    If no DB subnet group has been specified as part of the request and the
      PubliclyAccessible value has not been set, the DB instance will be publicly accessible. If a specific DB subnet group has been specified as part of the request and the PubliclyAccessible value has not been set, the DB instance will be private.

    Parameters: | auto_minor_version_upgrade (boolean) – Indicates that minor version upgrades will be applied automatically to the DB instance during the maintenance window. license_model (string) – License model information for the restored DB instance.

    Default: Same as source.

    Valid values: license-included | bring-your-own-license | `general-
      public-license`

    Parameters: | db_name (string) –

    The database name for the restored DB instance.

    This parameter doesn’t apply to the MySQL engine.

    Parameters: | engine (string) – The database engine to use for the new instance.

    Default: The same as source

    Constraint: Must be compatible with the engine of the source

    Example: oracle-ee

    Parameters: | iops (integer) – Specifies the amount of provisioned IOPS for the DB instance, expressed in I/O operations per second. If this parameter is not specified, the IOPS value will be taken from the backup. If this parameter is set to 0, the new instance will be converted to a non-PIOPS instance, which will take additional time, though your DB instance will be available for connections before the conversion starts.

    Constraints: Must be an integer greater than 1000.

    Parameters: | option_group_name (string) – The name of the option group to be used for the restored DB instance.

    Permanent options, such as the TDE option for Oracle Advanced Security
      TDE, cannot be removed from an option group, and that option group cannot be removed from a DB instance once it is associated with a DB instance

    Parameters: | tags (list) – A list of tags.

  `restore_db_instance_to_point_in_time`(source_db_instance_identifier, target_db_instance_identifier, restore_time=None, use_latest_restorable_time=None, db_instance_class=None, port=None, availability_zone=None, db_subnet_group_name=None, multi_az=None, publicly_accessible=None, auto_minor_version_upgrade=None, license_model=None, db_name=None, engine=None, iops=None, option_group_name=None, tags=None)

    Restores a DB instance to an arbitrary point-in-time. Users can restore to any point in time before the latestRestorableTime for up to backupRetentionPeriod days. The target database is created from the source database with the same configuration as the original database except that the DB instance is created with the default DB security group.

    Parameters: | source_db_instance_identifier (string) –

    The identifier of the source DB instance from which to restore.

    Constraints:

    - Must be the identifier of an existing database instance
    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | target_db_instance_identifier (string) –

    The name of the new database instance to be created.

    Constraints:

    - Must contain from 1 to 63 alphanumeric characters or hyphens
    - First character must be a letter
    - Cannot end with a hyphen or contain two consecutive hyphens

    Parameters: | restore_time (timestamp) – The date and time to restore from.

    Valid Values: Value must be a UTC time

    Constraints:

    - Must be before the latest restorable time for the DB instance
    - Cannot be specified if UseLatestRestorableTime parameter is true

    Example: 2009-09-07T23:45:00Z

    Parameters: | use_latest_restorable_time (boolean) – Specifies whether ( True) or not ( False) the DB instance is restored from the latest backup time.

    Default: False

    Constraints: Cannot be specified if RestoreTime parameter is provided.

    Parameters: | db_instance_class (string) – The compute and memory capacity of the Amazon RDS DB instance.

    Valid Values: `db.t1.micro | db.m1.small | db.m1.medium | db.m1.large |
      db.m1.xlarge | db.m2.2xlarge | db.m2.4xlarge`

    Default: The same DBInstanceClass as the original DB instance.

    Parameters: | port (integer) – The port number on which the database accepts connections.

    Constraints: Value must be 1150-65535

    Default: The same port as the original DB instance.

    Parameters: | availability_zone (string) – The EC2 Availability Zone that the database instance will be created in.

    Default: A random, system-chosen Availability Zone.

    Constraint: You cannot specify the AvailabilityZone parameter if the
      MultiAZ parameter is set to true.

    Example: us-east-1a

    Parameters: | db_subnet_group_name (string) – The DB subnet group name to use for the new instance. multi_az (boolean) – Specifies if the DB instance is a Multi-AZ deployment.

    Constraint: You cannot specify the AvailabilityZone parameter if the
      MultiAZ parameter is set to True.

    Parameters: | publicly_accessible (boolean) – Specifies the accessibility options for the DB instance. A value of true specifies an Internet-facing instance with a publicly resolvable DNS name, which resolves to a public IP address. A value of false specifies an internal instance with a DNS name that resolves to a private IP address.

    Default: The default behavior varies depending on whether a VPC has
      been requested or not. The following list shows the default behavior in each case.
    - **Default VPC:**true
    - **VPC:**false
    If no DB subnet group has been specified as part of the request and the
      PubliclyAccessible value has not been set, the DB instance will be publicly accessible. If a specific DB subnet group has been specified as part of the request and the PubliclyAccessible value has not been set, the DB instance will be private.

    Parameters: | auto_minor_version_upgrade (boolean) – Indicates that minor version upgrades will be applied automatically to the DB instance during the maintenance window. license_model (string) – License model information for the restored DB instance.

    Default: Same as source.

    Valid values: license-included | bring-your-own-license | `general-
      public-license`

    Parameters: | db_name (string) –

    The database name for the restored DB instance.

    This parameter is not used for the MySQL engine.

    Parameters: | engine (string) – The database engine to use for the new instance.

    Default: The same as source

    Constraint: Must be compatible with the engine of the source

    Example: oracle-ee

    Parameters: | iops (integer) – The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for the DB instance.

    Constraints: Must be an integer greater than 1000.

    Parameters: | option_group_name (string) – The name of the option group to be used for the restored DB instance.

    Permanent options, such as the TDE option for Oracle Advanced Security
      TDE, cannot be removed from an option group, and that option group cannot be removed from a DB instance once it is associated with a DB instance

    Parameters: | tags (list) – A list of tags.

  `revoke_db_security_group_ingress`(db_security_group_name, cidrip=None, ec2_security_group_name=None, ec2_security_group_id=None, ec2_security_group_owner_id=None)

    Revokes ingress from a DBSecurityGroup for previously authorized IP ranges or EC2 or VPC Security Groups. Required parameters for this API are one of CIDRIP, EC2SecurityGroupId for VPC, or (EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId).

    Parameters: | db_security_group_name (string) – The name of the DB security group to revoke ingress from. cidrip (string) – The IP range to revoke access from. Must be a valid CIDR range. If CIDRIP is specified, EC2SecurityGroupName, EC2SecurityGroupId and EC2SecurityGroupOwnerId cannot be provided. ec2_security_group_name (string) – The name of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. ec2_security_group_id (string) – The id of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided. ec2_security_group_owner_id (string) – The AWS Account Number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The AWS Access Key ID is not an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.27.0 »